@@ -148,11 +148,8 @@ class Rule(Address):
         self.rule_tokens, addr_str = Rule.part(rule_str)
         Address.__init__(self, addr_str)
 
-    def flat(self):
-        return Address.flat(self)+u''.join(self.rule_tokens)
-
     def __repr__(self):
-        return 'Rule(%r)' % self.flat()
+        return 'Rule(%r)' % (self.flat()+u''.join(self.rule_tokens))
 
     def match(self, addr):
 
@@ -210,7 +207,6 @@ class Rule(Address):
 
 import sqlite3
 import csv
-from functools import wraps
 
 class Directory(object):
 
@@ -300,6 +296,7 @@ class Directory(object):
         len_tokens = len(addr)
         for f in range(len_tokens):
             for l in range(f, len_tokens):
+                # only (a, b, c) -> (a, b, c); (a, c)
                 for s in range(1, 2+(f == 0 and l == 2)):
                     self.put_gradual(
                         addr.flat(f, l+1, s),
